##  Create Subscription Roles
Subscription roles define the involvement and responsibilities associated with maintaining fact sheet data. They reflect your organization's governance structure and roles. For more information, see [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.").
Define and create subscription roles that align with your organizational setup. For your initial assessment, you can create the following roles:
  * Application business owner (responsible): Responsible for the application's business performance and alignment with organizational goals.
  * Application technology owner (responsible): Responsible for the application's technical performance and IT alignment.
